@@ -1,6 +1,7 @@
-import requests
-from urllib.parse import urlencode, urlparse, quote_plus
 from base64 import b64encode
+from urllib.parse import urlencode
+
+import requests
 
 
 class Client:
@@ -117,7 +118,8 @@ class Client:
         if redirect_uri is not None and code is not None:
             url = self.flow_base_url + self.token_end
             authorization = '{0}:{1}'.format(self.client_id, self.client_secret)
-            header = {'Authorization': 'Basic {0}'.format(b64encode(authorization.encode('UTF-8')).decode('UTF-8'))}
+            header = {'content-type': 'application/x-www-form-urlencoded',
+                      'Authorization': 'Basic {0}'.format(b64encode(authorization.encode('UTF-8')).decode('UTF-8'))}
             args = {'grant_type': 'authorization_code', 'code': code, 'redirect_uri': redirect_uri}
             response = requests.post(url, headers=header, data=args)
             return self.parse_response(response)
@@ -127,13 +129,16 @@ class Client:
     def refresh_token(self, refresh_token):
         if refresh_token is not None:
             url = self.flow_base_url + self.token_end
+            authorization = '{0}:{1}'.format(self.client_id, self.client_secret)
+            header = {'content-type': 'application/x-www-form-urlencoded',
+                      'Authorization': 'Basic {0}'.format(b64encode(authorization.encode('UTF-8')).decode('UTF-8'))}
             data = {
                 'client_id': self.client_id,
                 'client_secret': self.client_secret,
                 'grant_type': "refresh_token",
                 'refresh_token': refresh_token,
             }
-            response = requests.post(url, data=data)
+            response = requests.post(url, headers=header, data=data)
             return self.parse_response(response)
         else:
             raise Exception("The attributes necessary to refresh the token were not obtained.")
@@ -172,6 +177,19 @@ class Client:
             params.update(kwargs)
             return self._post(endpoint, json=params)
 
+    # Pipeline section, see the api documentation: https://developers.pipedrive.com/docs/api/v1/#!/Pipelines
+    def get_pipelines(self, pipeline_id=None, **kwargs):
+        if pipeline_id is not None:
+            url = "pipelines/{0}".format(pipeline_id)
+        else:
+            url = "pipelines"
+        return self._get(url, **kwargs)
+
+    def get_pipeline_deals(self, pipeline_id, **kwargs):
+        if pipeline_id is not None:
+            url = "pipelines/{0}/deals".format(pipeline_id)
+        return self._get(url, **kwargs)
+
     # Deals section, see the api documentation: https://developers.pipedrive.com/docs/api/v1/#!/Deals
     def get_deals(self, deal_id=None, **kwargs):
         if deal_id is not None:
@@ -434,7 +452,7 @@ class Client:
             return self._delete(url)
         else:
             raise Exception("The attributes necessary to delete the webhook were not obtained.")
-    
+
     # Users section, see the api documentation: https://developers.pipedrive.com/docs/api/v1/#!/Users
     def get_users(self, user_id=None, **kwargs):
         if user_id is not None:
@@ -442,3 +460,7 @@ class Client:
         else:
             url = "users"
         return self._get(url, **kwargs)
+
+    def get_me(self, **kwargs):
+        url = "/users/me"
+        return self._get(url, **kwargs)
